# ngio API documentation

::: ngio
    options:
      members:
        - AxesSetup
        - ChannelSelectionModel
        - DefaultNgffVersion
        - Dimensions
        - ImageInWellPath
        - NgffVersions
        - NgioSupportedStore
        - PixelSize
        - Roi
        - RoiSlice
        - StoreOrGroup
        - create_synthetic_ome_zarr
